@@ -1,3 +1,4 @@
+import datetime
 import json
 import logging
 import os
@@ -55,6 +56,8 @@ class RDYFile:
         self.ntp_date_time: Optional[np.datetime64] = None
         self.device: Optional[Device] = None
 
+        self.duration: Optional[float] = None
+
         # Sensors
         self.sensors: Optional[List[Sensor]] = []
 
@@ -76,11 +79,20 @@ class RDYFile:
         if self.path:
             self.load_file(self.path)
 
-        if self.sync_method:
-            self._synchronize()
+            if self.timestamp_when_started and self.timestamp_when_stopped:
+                self.duration = (self.timestamp_when_stopped - self.timestamp_when_started) * 1e-9
+
+            if self.sync_method:
+                self._synchronize()
+        else:
+            logging.warning("RDYFile instantiated without a path")
 
         pass
 
+    # def __getitem__(self, idx):
+    #     key = list(self.measurements.keys())[idx]
+    #     return self.measurements[key]
+
     def __iter__(self):
         """
         The FileIterator returns the measurements iteratively
@@ -89,7 +101,9 @@ class RDYFile:
         return FileIterator(self)
 
     def __repr__(self):
-        return "%s" % self.name
+        return "Filename: %s, T0: %s, Duration: %s" % (self.name,
+                                                       str(self.t0),
+                                                       str(datetime.timedelta(seconds=self.duration)))
 
     def _synchronize(self):
         if self.sync_method == "timestamp":
@@ -133,7 +147,40 @@ class RDYFile:
             raise ValueError("sync_method must 'timestamp', 'device_time', 'gps_time' or 'ntp_time' not %s" % self.sync_method)
         pass
 
+    def get_integrity_report(self):
+        """
+        Returns a dict object with information of the rdy file
+        Returns
+        -------
+        Data Integrity Report
+        """
+        report = {}
+
+        for k, v in self.measurements.items():
+            if len(v) > 0:
+                report[k.__name__] = True
+            else:
+                report[k.__name__] = False
+
+        attr = self.__dict__.copy()
+        attr.update(attr["device"].__dict__.copy())
+        for a in ["db_con", "measurements", "device", "sensors"]:
+            attr.pop(a)
+            pass
+
+        report.update(attr)
+
+        return report
+
     def load_file(self, path: str):
+        """
+        Loads a single Ridy file located at path
+
+        Parameters
+        ----------
+        path Path to the ridy file
+
+        """
         logger.info("Loading file: %s" % path)
 
         _, self.extension = os.path.splitext(path)
